Class: Aws::EMRContainers::Types::CreateManagedEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::CreateManagedEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_arn ⇒ String
The certificate ARN provided by users for the managed endpoint.
-
#client_token ⇒ String
The client idempotency token for this create call.
-
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that will be used to override existing configurations.
-
#execution_role_arn ⇒ String
The ARN of the execution role.
-
#name ⇒ String
The name of the managed endpoint.
-
#release_label ⇒ String
The Amazon EMR release version.
-
#session_idle_timeout_in_minutes ⇒ Integer
The number of idle minutes before the managed endpoint session times out.
-
#tags ⇒ Hash<String,String>
The tags of the managed endpoint.
-
#type ⇒ String
The type of the managed endpoint.
-
#virtual_cluster_id ⇒ String
The ID of the virtual cluster for which a managed endpoint is created.
Instance Attribute Details
#certificate_arn ⇒ String
The certificate ARN provided by users for the managed endpoint. This field is under deprecation and will be removed in future releases.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The client idempotency token for this create call.
A suitable default value is auto-generated. You should normally not need to pass this option.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that will be used to override existing configurations.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the execution role.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the managed endpoint.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The Amazon EMR release version.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#session_idle_timeout_in_minutes ⇒ Integer
The number of idle minutes before the managed endpoint session times out.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the managed endpoint.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the managed endpoint.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |
#virtual_cluster_id ⇒ String
The ID of the virtual cluster for which a managed endpoint is created.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 363 class CreateManagedEndpointRequest < Struct.new( :name, :virtual_cluster_id, :type, :release_label, :execution_role_arn, :certificate_arn, :configuration_overrides, :client_token, :tags, :session_idle_timeout_in_minutes) SENSITIVE = [] include Aws::Structure end |