Class: Aws::EMRContainers::Types::CreateVirtualClusterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::CreateVirtualClusterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token of the virtual cluster.
-
#container_provider ⇒ Types::ContainerProvider
The container provider of the virtual cluster.
-
#name ⇒ String
The specified name of the virtual cluster.
-
#scheduler_configuration ⇒ Types::SchedulerConfiguration
The scheduler configuration (concurrency and queue limits) to apply to the virtual cluster at creation time.
-
#security_configuration_id ⇒ String
The ID of the security configuration.
-
#session_enabled ⇒ Boolean
Indicates whether the virtual cluster has session support enabled.
-
#tags ⇒ Hash<String,String>
The tags assigned to the virtual cluster.
Instance Attribute Details
#client_token ⇒ String
The client token of the virtual cluster.
A suitable default value is auto-generated. You should normally not need to pass this option.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |
#container_provider ⇒ Types::ContainerProvider
The container provider of the virtual cluster.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The specified name of the virtual cluster.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |
#scheduler_configuration ⇒ Types::SchedulerConfiguration
The scheduler configuration (concurrency and queue limits) to apply to the virtual cluster at creation time. When omitted, no limits are applied.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |
#security_configuration_id ⇒ String
The ID of the security configuration.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |
#session_enabled ⇒ Boolean
Indicates whether the virtual cluster has session support enabled.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags assigned to the virtual cluster.
498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 498 class CreateVirtualClusterRequest < Struct.new( :name, :container_provider, :client_token, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration) SENSITIVE = [] include Aws::Structure end |