Class: Aws::EMRContainers::Types::DescribeJobTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::DescribeJobTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the job template that will be described.
Instance Attribute Details
#id ⇒ String
The ID of the job template that will be described.
643 644 645 646 647 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 643 class DescribeJobTemplateRequest < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |