Class: Aws::EMRContainers::Types::Endpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrcontainers/types.rb

Overview

This entity represents the endpoint that is managed by Amazon EMR on EKS.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#auth_proxy_urlString

The auth proxy URL of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_arnString

The certificate ARN of the endpoint. This field is under deprecation and will be removed in future.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#certificate_authorityTypes::Certificate

The certificate generated by emr control plane on customer behalf to secure the managed endpoint.

Returns:



915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_overridesTypes::ConfigurationOverrides

The configuration settings that are used to override existing configurations for endpoints.



915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the endpoint was created.

Returns:

  • (Time)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The execution role ARN of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reasons why the endpoint has failed.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#release_labelString

The EMR release version to be used for the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupString

The security group configuration of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#server_urlString

The server URL of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state_detailsString

Additional details of the endpoint state.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The subnet IDs of the endpoint.

Returns:

  • (Array<String>)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of the endpoint.

Returns:

  • (Hash<String,String>)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the endpoint.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_cluster_idString

The ID of the endpoint's virtual cluster.

Returns:

  • (String)


915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915

class Endpoint < Struct.new(
  :id,
  :name,
  :arn,
  :virtual_cluster_id,
  :type,
  :state,
  :release_label,
  :execution_role_arn,
  :certificate_arn,
  :certificate_authority,
  :configuration_overrides,
  :server_url,
  :auth_proxy_url,
  :created_at,
  :security_group,
  :subnet_ids,
  :state_details,
  :failure_reason,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end