Class: Aws::EMRContainers::Types::IAMConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::IAMConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
Contains the IAM settings for a security configuration, including the system role used for authentication.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#system_role ⇒ String
The Amazon Resource Name (ARN) of the system role used by the security configuration.
Instance Attribute Details
#system_role ⇒ String
The Amazon Resource Name (ARN) of the system role used by the security configuration.
1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1033 class IAMConfiguration < Struct.new( :system_role) SENSITIVE = [] include Aws::Structure end |