Class: Aws::EMRContainers::Types::JobRun
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::JobRun
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
This entity describes a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of job run.
-
#client_token ⇒ String
The client token used to start a job run.
-
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that are used to override default configuration.
-
#created_at ⇒ Time
The date and time when the job run was created.
-
#created_by ⇒ String
The user who created the job run.
-
#execution_role_arn ⇒ String
The execution role ARN of the job run.
-
#failure_reason ⇒ String
The reasons why the job run has failed.
-
#finished_at ⇒ Time
The date and time when the job run has finished.
-
#id ⇒ String
The ID of the job run.
-
#job_driver ⇒ Types::JobDriver
Parameters of job driver for the job run.
-
#name ⇒ String
The name of the job run.
-
#release_label ⇒ String
The release version of Amazon EMR.
-
#retry_policy_configuration ⇒ Types::RetryPolicyConfiguration
The configuration of the retry policy that the job runs on.
-
#retry_policy_execution ⇒ Types::RetryPolicyExecution
The current status of the retry policy executed on the job.
-
#state ⇒ String
The state of the job run.
-
#state_details ⇒ String
Additional details of the job run state.
-
#tags ⇒ Hash<String,String>
The assigned tags of the job run.
-
#virtual_cluster_id ⇒ String
The ID of the job run's virtual cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The client token used to start a job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that are used to override default configuration.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the job run was created.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user who created the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN of the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reasons why the job run has failed.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#finished_at ⇒ Time
The date and time when the job run has finished.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#job_driver ⇒ Types::JobDriver
Parameters of job driver for the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The release version of Amazon EMR.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#retry_policy_configuration ⇒ Types::RetryPolicyConfiguration
The configuration of the retry policy that the job runs on.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#retry_policy_execution ⇒ Types::RetryPolicyExecution
The current status of the retry policy executed on the job.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
Additional details of the job run state.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The assigned tags of the job run.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |
#virtual_cluster_id ⇒ String
The ID of the job run's virtual cluster.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1202 class JobRun < Struct.new( :id, :name, :virtual_cluster_id, :arn, :state, :client_token, :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :created_at, :created_by, :finished_at, :state_details, :failure_reason, :tags, :retry_policy_configuration, :retry_policy_execution) SENSITIVE = [] include Aws::Structure end |