Class: Aws::EMRContainers::Types::JobTemplateData
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::JobTemplateData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
The values of StartJobRun API requests used in job runs started using the job template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_overrides ⇒ Types::ParametricConfigurationOverrides
The configuration settings that are used to override defaults configuration.
-
#execution_role_arn ⇒ String
The execution role ARN of the job run.
-
#job_driver ⇒ Types::JobDriver
Specify the driver that the job runs on.
-
#job_tags ⇒ Hash<String,String>
The tags assigned to jobs started using the job template.
-
#parameter_configuration ⇒ Hash<String,Types::TemplateParameterConfiguration>
The configuration of parameters existing in the job template.
-
#release_label ⇒ String
The release version of Amazon EMR.
Instance Attribute Details
#configuration_overrides ⇒ Types::ParametricConfigurationOverrides
The configuration settings that are used to override defaults configuration.
1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1315 class JobTemplateData < Struct.new( :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :parameter_configuration, :job_tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN of the job run.
1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1315 class JobTemplateData < Struct.new( :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :parameter_configuration, :job_tags) SENSITIVE = [] include Aws::Structure end |
#job_driver ⇒ Types::JobDriver
Specify the driver that the job runs on. Exactly one of the two available job drivers is required, either sparkSqlJobDriver or sparkSubmitJobDriver.
1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1315 class JobTemplateData < Struct.new( :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :parameter_configuration, :job_tags) SENSITIVE = [] include Aws::Structure end |
#job_tags ⇒ Hash<String,String>
The tags assigned to jobs started using the job template.
1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1315 class JobTemplateData < Struct.new( :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :parameter_configuration, :job_tags) SENSITIVE = [] include Aws::Structure end |
#parameter_configuration ⇒ Hash<String,Types::TemplateParameterConfiguration>
The configuration of parameters existing in the job template.
1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1315 class JobTemplateData < Struct.new( :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :parameter_configuration, :job_tags) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The release version of Amazon EMR.
1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1315 class JobTemplateData < Struct.new( :execution_role_arn, :release_label, :configuration_overrides, :job_driver, :parameter_configuration, :job_tags) SENSITIVE = [] include Aws::Structure end |