Class: Aws::EMRContainers::Types::LakeFormationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::LakeFormationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
Lake Formation related configuration inputs for the security configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorized_session_tag_value ⇒ String
The session tag to authorize Amazon EMR on EKS for API calls to Lake Formation.
-
#query_engine_role_arn ⇒ String
The query engine IAM role ARN that is tied to the secure Spark job.
-
#secure_namespace_info ⇒ Types::SecureNamespaceInfo
The namespace input of the system job.
Instance Attribute Details
#authorized_session_tag_value ⇒ String
The session tag to authorize Amazon EMR on EKS for API calls to Lake Formation.
1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1346 class LakeFormationConfiguration < Struct.new( :authorized_session_tag_value, :secure_namespace_info, :query_engine_role_arn) SENSITIVE = [] include Aws::Structure end |
#query_engine_role_arn ⇒ String
The query engine IAM role ARN that is tied to the secure Spark job.
The QueryEngine role assumes the JobExecutionRole to execute all
the Lake Formation calls.
1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1346 class LakeFormationConfiguration < Struct.new( :authorized_session_tag_value, :secure_namespace_info, :query_engine_role_arn) SENSITIVE = [] include Aws::Structure end |
#secure_namespace_info ⇒ Types::SecureNamespaceInfo
The namespace input of the system job.
1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1346 class LakeFormationConfiguration < Struct.new( :authorized_session_tag_value, :secure_namespace_info, :query_engine_role_arn) SENSITIVE = [] include Aws::Structure end |