Class: Aws::EMRContainers::Types::ListManagedEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrcontainers/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_afterTime

The date and time after which the endpoints are created.

Returns:

  • (Time)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#created_beforeTime

The date and time before which the endpoints are created.

Returns:

  • (Time)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of managed endpoints that can be listed.

Returns:

  • (Integer)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of managed endpoints to return.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statesArray<String>

The states of the managed endpoints.

Returns:

  • (Array<String>)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#typesArray<String>

The types of the managed endpoints.

Returns:

  • (Array<String>)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#virtual_cluster_idString

The ID of the virtual cluster.

Returns:

  • (String)


1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1487

class ListManagedEndpointsRequest < Struct.new(
  :virtual_cluster_id,
  :created_before,
  :created_after,
  :types,
  :states,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end