Class: Aws::EMRContainers::Types::ParametricCloudWatchMonitoringConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrcontainers/types.rb

Overview

A configuration for CloudWatch monitoring. You can configure your jobs to send log information to CloudWatch Logs. This data type allows job template parameters to be specified within.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_nameString

The name of the log group for log publishing.

Returns:

  • (String)


1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1722

class ParametricCloudWatchMonitoringConfiguration < Struct.new(
  :log_group_name,
  :log_stream_name_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#log_stream_name_prefixString

The specified name prefix for log streams.

Returns:

  • (String)


1722
1723
1724
1725
1726
1727
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1722

class ParametricCloudWatchMonitoringConfiguration < Struct.new(
  :log_group_name,
  :log_stream_name_prefix)
  SENSITIVE = []
  include Aws::Structure
end