Class: Aws::EMRContainers::Types::UpdateVirtualClusterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrcontainers/types.rb

Overview

Contains the parameters for a request to update a virtual cluster on Amazon EMR on EKS.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2256
2257
2258
2259
2260
2261
2262
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2256

class UpdateVirtualClusterRequest < Struct.new(
  :id,
  :scheduler_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the virtual cluster to update.

Returns:

  • (String)


2256
2257
2258
2259
2260
2261
2262
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2256

class UpdateVirtualClusterRequest < Struct.new(
  :id,
  :scheduler_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduler_configurationTypes::SchedulerConfiguration

The scheduler configuration to apply to the virtual cluster. The new configuration fully replaces the existing one. If you omit a field, the corresponding limit is removed.



2256
2257
2258
2259
2260
2261
2262
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2256

class UpdateVirtualClusterRequest < Struct.new(
  :id,
  :scheduler_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end