Class: Aws::EMRContainers::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EMRContainers::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-emrcontainers/client.rb,
sig/client.rbs
Overview
An API client for EMRContainers. To construct a client, you need to configure a :region and :credentials.
client = Aws::EMRContainers::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelJobRunResponseSuccess, _CreateJobTemplateResponseSuccess, _CreateManagedEndpointResponseSuccess, _CreateSecurityConfigurationResponseSuccess, _CreateVirtualClusterResponseSuccess, _DeleteJobTemplateResponseSuccess, _DeleteManagedEndpointResponseSuccess, _DeleteVirtualClusterResponseSuccess, _DescribeJobRunResponseSuccess, _DescribeJobTemplateResponseSuccess, _DescribeManagedEndpointResponseSuccess, _DescribeSecurityConfigurationResponseSuccess, _DescribeVirtualClusterResponseSuccess, _GetManagedEndpointSessionCredentialsResponseSuccess, _ListJobRunsResponseSuccess, _ListJobTemplatesResponseSuccess, _ListManagedEndpointsResponseSuccess, _ListSecurityConfigurationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVirtualClustersResponseSuccess, _StartJobRunResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_job_run(params = {}) ⇒ Types::CancelJobRunResponse
Cancels a job run.
-
#create_job_template(params = {}) ⇒ Types::CreateJobTemplateResponse
Creates a job template.
-
#create_managed_endpoint(params = {}) ⇒ Types::CreateManagedEndpointResponse
Creates a managed endpoint.
-
#create_security_configuration(params = {}) ⇒ Types::CreateSecurityConfigurationResponse
Creates a security configuration.
-
#create_virtual_cluster(params = {}) ⇒ Types::CreateVirtualClusterResponse
Creates a virtual cluster.
-
#delete_job_template(params = {}) ⇒ Types::DeleteJobTemplateResponse
Deletes a job template.
-
#delete_managed_endpoint(params = {}) ⇒ Types::DeleteManagedEndpointResponse
Deletes a managed endpoint.
-
#delete_virtual_cluster(params = {}) ⇒ Types::DeleteVirtualClusterResponse
Deletes a virtual cluster.
-
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Displays detailed information about a job run.
-
#describe_job_template(params = {}) ⇒ Types::DescribeJobTemplateResponse
Displays detailed information about a specified job template.
-
#describe_managed_endpoint(params = {}) ⇒ Types::DescribeManagedEndpointResponse
Displays detailed information about a managed endpoint.
-
#describe_security_configuration(params = {}) ⇒ Types::DescribeSecurityConfigurationResponse
Displays detailed information about a specified security configuration.
-
#describe_virtual_cluster(params = {}) ⇒ Types::DescribeVirtualClusterResponse
Displays detailed information about a specified virtual cluster.
-
#get_managed_endpoint_session_credentials(params = {}) ⇒ Types::GetManagedEndpointSessionCredentialsResponse
Generate a session token to connect to a managed endpoint.
-
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists job runs based on a set of parameters.
-
#list_job_templates(params = {}) ⇒ Types::ListJobTemplatesResponse
Lists job templates based on a set of parameters.
-
#list_managed_endpoints(params = {}) ⇒ Types::ListManagedEndpointsResponse
Lists managed endpoints based on a set of parameters.
-
#list_security_configurations(params = {}) ⇒ Types::ListSecurityConfigurationsResponse
Lists security configurations based on a set of parameters.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to the resources.
-
#list_virtual_clusters(params = {}) ⇒ Types::ListVirtualClustersResponse
Lists information about the specified virtual cluster.
-
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Starts a job run.
-
#tag_resource(params = {}) ⇒ Struct
Assigns tags to resources.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from resources.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-emrcontainers/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2006 2007 2008 |
# File 'lib/aws-sdk-emrcontainers/client.rb', line 2006 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2009 2010 2011 |
# File 'lib/aws-sdk-emrcontainers/client.rb', line 2009 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 |
# File 'lib/aws-sdk-emrcontainers/client.rb', line 1979 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EMRContainers') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-emrcontainers' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job_run(params = {}) ⇒ Types::CancelJobRunResponse
Cancels a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
87 |
# File 'sig/client.rbs', line 87
def cancel_job_run: (
|
#create_job_template(params = {}) ⇒ Types::CreateJobTemplateResponse
Creates a job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
101 |
# File 'sig/client.rbs', line 101
def create_job_template: (
|
#create_managed_endpoint(params = {}) ⇒ Types::CreateManagedEndpointResponse
Creates a managed endpoint. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
146 |
# File 'sig/client.rbs', line 146
def create_managed_endpoint: (
|
#create_security_configuration(params = {}) ⇒ Types::CreateSecurityConfigurationResponse
Creates a security configuration. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
167 |
# File 'sig/client.rbs', line 167
def create_security_configuration: (
|
#create_virtual_cluster(params = {}) ⇒ Types::CreateVirtualClusterResponse
Creates a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
203 |
# File 'sig/client.rbs', line 203
def create_virtual_cluster: (
|
#delete_job_template(params = {}) ⇒ Types::DeleteJobTemplateResponse
Deletes a job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
218 |
# File 'sig/client.rbs', line 218
def delete_job_template: (
|
#delete_managed_endpoint(params = {}) ⇒ Types::DeleteManagedEndpointResponse
Deletes a managed endpoint. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
229 |
# File 'sig/client.rbs', line 229
def delete_managed_endpoint: (
|
#delete_virtual_cluster(params = {}) ⇒ Types::DeleteVirtualClusterResponse
Deletes a virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
240 |
# File 'sig/client.rbs', line 240
def delete_virtual_cluster: (
|
#describe_job_run(params = {}) ⇒ Types::DescribeJobRunResponse
Displays detailed information about a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
250 |
# File 'sig/client.rbs', line 250
def describe_job_run: (
|
#describe_job_template(params = {}) ⇒ Types::DescribeJobTemplateResponse
Displays detailed information about a specified job template. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
261 |
# File 'sig/client.rbs', line 261
def describe_job_template: (
|
#describe_managed_endpoint(params = {}) ⇒ Types::DescribeManagedEndpointResponse
Displays detailed information about a managed endpoint. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
271 |
# File 'sig/client.rbs', line 271
def describe_managed_endpoint: (
|
#describe_security_configuration(params = {}) ⇒ Types::DescribeSecurityConfigurationResponse
Displays detailed information about a specified security configuration. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
282 |
# File 'sig/client.rbs', line 282
def describe_security_configuration: (
|
#describe_virtual_cluster(params = {}) ⇒ Types::DescribeVirtualClusterResponse
Displays detailed information about a specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
292 |
# File 'sig/client.rbs', line 292
def describe_virtual_cluster: (
|
#get_managed_endpoint_session_credentials(params = {}) ⇒ Types::GetManagedEndpointSessionCredentialsResponse
Generate a session token to connect to a managed endpoint.
305 |
# File 'sig/client.rbs', line 305
def get_managed_endpoint_session_credentials: (
|
#list_job_runs(params = {}) ⇒ Types::ListJobRunsResponse
Lists job runs based on a set of parameters. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
322 |
# File 'sig/client.rbs', line 322
def list_job_runs: (
|
#list_job_templates(params = {}) ⇒ Types::ListJobTemplatesResponse
Lists job templates based on a set of parameters. Job template stores values of StartJobRun API request in a template and can be used to start a job run. Job template allows two use cases: avoid repeating recurring StartJobRun API request values, enforcing certain values in StartJobRun API request.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
339 |
# File 'sig/client.rbs', line 339
def list_job_templates: (
|
#list_managed_endpoints(params = {}) ⇒ Types::ListManagedEndpointsResponse
Lists managed endpoints based on a set of parameters. A managed endpoint is a gateway that connects Amazon EMR Studio to Amazon EMR on EKS so that Amazon EMR Studio can communicate with your virtual cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
353 |
# File 'sig/client.rbs', line 353
def list_managed_endpoints: (
|
#list_security_configurations(params = {}) ⇒ Types::ListSecurityConfigurationsResponse
Lists security configurations based on a set of parameters. Security configurations in Amazon EMR on EKS are templates for different security setups. You can use security configurations to configure the Lake Formation integration setup. You can also create a security configuration to re-use a security setup each time you create a virtual cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
370 |
# File 'sig/client.rbs', line 370
def list_security_configurations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags assigned to the resources.
383 |
# File 'sig/client.rbs', line 383
def list_tags_for_resource: (
|
#list_virtual_clusters(params = {}) ⇒ Types::ListVirtualClustersResponse
Lists information about the specified virtual cluster. Virtual cluster is a managed entity on Amazon EMR on EKS. You can create, describe, list and delete virtual clusters. They do not consume any additional resource in your system. A single virtual cluster maps to a single Kubernetes namespace. Given this relationship, you can model virtual clusters the same way you model Kubernetes namespaces to meet your requirements.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
394 |
# File 'sig/client.rbs', line 394
def list_virtual_clusters: (
|
#start_job_run(params = {}) ⇒ Types::StartJobRunResponse
Starts a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.
414 |
# File 'sig/client.rbs', line 414
def start_job_run: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns tags to resources. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value, both of which you define. Tags enable you to categorize your Amazon Web Services resources by attributes such as purpose, owner, or environment. When you have many resources of the same type, you can quickly identify a specific resource based on the tags you've assigned to it. For example, you can define a set of tags for your Amazon EMR on EKS clusters to help you track each cluster's owner and stack level. We recommend that you devise a consistent set of tag keys for each resource type. You can then search and filter the resources based on the tags that you add.
435 |
# File 'sig/client.rbs', line 435
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from resources.
445 |
# File 'sig/client.rbs', line 445
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1999 2000 2001 |
# File 'lib/aws-sdk-emrcontainers/client.rb', line 1999 def waiter_names [] end |