Class: Aws::EMRContainers::Types::Endpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::Endpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
This entity represents the endpoint that is managed by Amazon EMR on EKS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the endpoint.
-
#auth_proxy_url ⇒ String
The auth proxy URL of the endpoint.
-
#certificate_arn ⇒ String
The certificate ARN of the endpoint.
-
#certificate_authority ⇒ Types::Certificate
The certificate generated by emr control plane on customer behalf to secure the managed endpoint.
-
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that are used to override existing configurations for endpoints.
-
#created_at ⇒ Time
The date and time when the endpoint was created.
-
#execution_role_arn ⇒ String
The execution role ARN of the endpoint.
-
#failure_reason ⇒ String
The reasons why the endpoint has failed.
-
#id ⇒ String
The ID of the endpoint.
-
#name ⇒ String
The name of the endpoint.
-
#release_label ⇒ String
The EMR release version to be used for the endpoint.
-
#security_group ⇒ String
The security group configuration of the endpoint.
-
#server_url ⇒ String
The server URL of the endpoint.
-
#state ⇒ String
The state of the endpoint.
-
#state_details ⇒ String
Additional details of the endpoint state.
-
#subnet_ids ⇒ Array<String>
The subnet IDs of the endpoint.
-
#tags ⇒ Hash<String,String>
The tags of the endpoint.
-
#type ⇒ String
The type of the endpoint.
-
#virtual_cluster_id ⇒ String
The ID of the endpoint's virtual cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#auth_proxy_url ⇒ String
The auth proxy URL of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#certificate_arn ⇒ String
The certificate ARN of the endpoint. This field is under deprecation and will be removed in future.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#certificate_authority ⇒ Types::Certificate
The certificate generated by emr control plane on customer behalf to secure the managed endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#configuration_overrides ⇒ Types::ConfigurationOverrides
The configuration settings that are used to override existing configurations for endpoints.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the endpoint was created.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reasons why the endpoint has failed.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#release_label ⇒ String
The EMR release version to be used for the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#security_group ⇒ String
The security group configuration of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#server_url ⇒ String
The server URL of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
Additional details of the endpoint state.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The subnet IDs of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the endpoint.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#virtual_cluster_id ⇒ String
The ID of the endpoint's virtual cluster.
915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 915 class Endpoint < Struct.new( :id, :name, :arn, :virtual_cluster_id, :type, :state, :release_label, :execution_role_arn, :certificate_arn, :certificate_authority, :configuration_overrides, :server_url, :auth_proxy_url, :created_at, :security_group, :subnet_ids, :state_details, :failure_reason, :tags) SENSITIVE = [] include Aws::Structure end |