Class: Aws::EMRContainers::Types::IAMConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::IAMConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
IAM configuration for the security configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#system_role ⇒ String
The ARN of the system role used by the security configuration.
Instance Attribute Details
#system_role ⇒ String
The ARN of the system role used by the security configuration.
1023 1024 1025 1026 1027 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1023 class IAMConfiguration < Struct.new( :system_role) SENSITIVE = [] include Aws::Structure end |