Class: Aws::EMRContainers::Types::SchedulerStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::SchedulerStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
The current job-run counts for a virtual cluster, reflecting how much of the configured scheduler capacity is in use.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_concurrent_job_runs ⇒ Integer
The number of job runs currently in the
RUNNINGstate for the virtual cluster. -
#current_in_queue_job_runs ⇒ Integer
The number of job runs currently waiting in the queue (
PENDINGorSUBMITTED) for the virtual cluster.
Instance Attribute Details
#current_concurrent_job_runs ⇒ Integer
The number of job runs currently in the RUNNING state for the
virtual cluster.
1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1909 class SchedulerStatus < Struct.new( :current_in_queue_job_runs, :current_concurrent_job_runs) SENSITIVE = [] include Aws::Structure end |
#current_in_queue_job_runs ⇒ Integer
The number of job runs currently waiting in the queue (PENDING or
SUBMITTED) for the virtual cluster.
1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 1909 class SchedulerStatus < Struct.new( :current_in_queue_job_runs, :current_concurrent_job_runs) SENSITIVE = [] include Aws::Structure end |