Class: Aws::EMRContainers::Types::VirtualCluster
- Inherits:
-
Struct
- Object
- Struct
- Aws::EMRContainers::Types::VirtualCluster
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-emrcontainers/types.rb
Overview
This entity describes a virtual cluster. A virtual cluster is a Kubernetes namespace that Amazon EMR is registered with. Amazon EMR uses virtual clusters to run jobs and host endpoints. Multiple virtual clusters can be backed by the same physical cluster. However, each virtual cluster maps to one namespace on an Amazon EKS cluster. Virtual clusters do not create any active resources that contribute to your bill or that require lifecycle management outside the service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the virtual cluster.
-
#container_provider ⇒ Types::ContainerProvider
The container provider of the virtual cluster.
-
#created_at ⇒ Time
The date and time when the virtual cluster is created.
-
#id ⇒ String
The ID of the virtual cluster.
-
#name ⇒ String
The name of the virtual cluster.
-
#scheduler_configuration ⇒ Types::SchedulerConfiguration
The scheduler configuration (concurrency and queue limits) applied to the virtual cluster.
-
#scheduler_status ⇒ Types::SchedulerStatus
The current in-queue and concurrent job-run counts for the virtual cluster.
-
#security_configuration_id ⇒ String
The ID of the security configuration.
-
#session_enabled ⇒ Boolean
Specifies whether the virtual cluster has session support enabled.
-
#state ⇒ String
The state of the virtual cluster.
-
#tags ⇒ Hash<String,String>
The assigned tags of the virtual cluster.
Instance Attribute Details
#arn ⇒ String
The ARN of the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#container_provider ⇒ Types::ContainerProvider
The container provider of the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the virtual cluster is created.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#scheduler_configuration ⇒ Types::SchedulerConfiguration
The scheduler configuration (concurrency and queue limits) applied to the virtual cluster. The service does not return this field when no scheduler limits are configured.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#scheduler_status ⇒ Types::SchedulerStatus
The current in-queue and concurrent job-run counts for the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#security_configuration_id ⇒ String
The ID of the security configuration.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#session_enabled ⇒ Boolean
Specifies whether the virtual cluster has session support enabled.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The assigned tags of the virtual cluster.
2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2349 class VirtualCluster < Struct.new( :id, :name, :arn, :state, :container_provider, :created_at, :tags, :security_configuration_id, :session_enabled, :scheduler_configuration, :scheduler_status) SENSITIVE = [] include Aws::Structure end |