Class: Aws::EMRContainers::Types::VirtualCluster

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-emrcontainers/types.rb

Overview

This entity describes a virtual cluster. A virtual cluster is a Kubernetes namespace that Amazon EMR is registered with. Amazon EMR uses virtual clusters to run jobs and host endpoints. Multiple virtual clusters can be backed by the same physical cluster. However, each virtual cluster maps to one namespace on an Amazon EKS cluster. Virtual clusters do not create any active resources that contribute to your bill or that require lifecycle management outside the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the virtual cluster.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#container_providerTypes::ContainerProvider

The container provider of the virtual cluster.



2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the virtual cluster is created.

Returns:

  • (Time)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the virtual cluster.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the virtual cluster.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#security_configuration_idString

The ID of the security configuration.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#session_enabledBoolean

Indicates whether the virtual cluster has session support enabled.

Returns:

  • (Boolean)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the virtual cluster.

Returns:

  • (String)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The assigned tags of the virtual cluster.

Returns:

  • (Hash<String,String>)


2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
# File 'lib/aws-sdk-emrcontainers/types.rb', line 2226

class VirtualCluster < Struct.new(
  :id,
  :name,
  :arn,
  :state,
  :container_provider,
  :created_at,
  :tags,
  :security_configuration_id,
  :session_enabled)
  SENSITIVE = []
  include Aws::Structure
end